@@ -8,7 +8,7 @@ import Image as mod_image
 import ImageDraw as mod_imagedraw
 import ImageFont as mod_imagefont
 
-__version__ = '0.1.2'
+__version__ = '0.1.3'
 
 DEFAULT_AXES_COLOR = ( 150, 150, 150 )
 DEFAULT_LABEL_COLOR = ( 150, 150, 150 )
@@ -58,7 +58,10 @@ def min_max( *n ):
 	return min_result, max_result
 			
 class Bounds:
-	""" Bounds for coordinate system and image size. """
+	"""
+	Bounds for coordinate system and image size. If the user don't explicitly set hiw own bounds, those
+	will be resized with each new element.
+	"""
 
 	image_width = None
 	image_height = None
@@ -173,12 +176,14 @@ class CoordinateSystem:
 
 		# By default, axes are on:
 		self.x_axis = Axis( horizontal = True, points = 1 )
-		self.y_axis = Axis( horizontal = False, points = 1 )
+		self.y_axis = Axis( vertical = True, points = 1 )
 
 	def add( self, element ):
 		"""
-		Add element on coordinate system. Note that if you add an axis, it will remove a
-		previous existing horizontal/vertical axis.
+		Add element on coordinate system.
+
+		Note that if you add n default axis, it will remove a previous existing horizontal/vertical axis,
+		but the same does not apply for detached axes.
 		"""
 		assert element
 		assert isinstance( element, CoordinateSystemElement )
@@ -282,6 +287,13 @@ class CoordinateSystemElement:
 			image.paste( tmp_image, mask = tmp_image )
 
 class Axis( CoordinateSystemElement ):
+	"""
+	Axis class.
+
+	Axis can be horizontal or vertical.
+
+	Axis can, also, be default ( (0,0) as center) or detached (if (0,0) if not the center).
+	"""
 
 	horizontal = None
 	color = None
@@ -298,12 +310,15 @@ class Axis( CoordinateSystemElement ):
 
 	center = None
 
-	def __init__( self, horizontal, color = None, labels = None, label_color = None,
+	def __init__( self, horizontal = False, vertical = False, color = None, labels = None, label_color = None,
 			label_position = None, points = None, transparency_mask = None, hide_positive = False,
 			hide_negative = False, hide = False, detached_center = None ):
 		CoordinateSystemElement.__init__( self, transparency_mask = transparency_mask )
 
+		assert bool( horizontal ) != bool( vertical ), 'Axis must be set to be horizontal or vertical'
+
 		self.horizontal = horizontal
+
 		self.color = color if color else DEFAULT_AXES_COLOR
 		self.label_color = label_color if label_color else DEFAULT_LABEL_COLOR
 
